﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using ThinkGeo.MapSuite.Core;

namespace GetColumnsTest
{
    class Program
    {
        static void Main(string[] args)
        {

            // This test is built using 9.0.0.484

            InMemoryFeatureLayer imfl = new InMemoryFeatureLayer();
            
            imfl.Open();
            imfl.Columns.Add(new FeatureSourceColumn("Test1", "INT", 5));
            imfl.Columns.Add(new FeatureSourceColumn("Test2", "TEXT", 5));
            imfl.Columns.Add(new FeatureSourceColumn("Test3", "INT", 5));
            imfl.Close();

            PointShape point = new PointShape(0, 0);
            Feature feature = new Feature(point, new string[] { "Test1:1", "Test2:Two", "Test3:3" });

            imfl.InternalFeatures.Add("key", feature);

            Collection<FeatureSourceColumn> columns = GetColumns(imfl);

            string msg = "The following feature source columns are in the fl:\n";
            foreach (FeatureSourceColumn col in columns)
            {
                msg += col.ColumnName + ", ";
            }

            Console.WriteLine(msg);

            msg = "";

            msg = "The following columns are in the actual feature:\n";
            foreach (KeyValuePair<string, string> col in imfl.InternalFeatures[0].ColumnValues)
            {
                msg += col.Key + ", ";
            }

            Console.WriteLine(msg);
        }

        // Notice that we pass in a FeatureLayer
        public static Collection<FeatureSourceColumn> GetColumns(FeatureLayer fl)
        {
            fl.Open();
            
            // Calling this function will wipe out the columns
            WellKnownType type = fl.FeatureSource.GetFirstFeaturesWellKnownType();

            // But, even if we disable GetFirstFeaturesWellKnownType, GetColumns also
            // will wipe out the columns
            Collection<FeatureSourceColumn> columns = fl.FeatureSource.GetColumns();

            return columns;
        }

    }
}
